]> git.dujemihanovic.xyz Git - u-boot.git/commitdiff
fs: Use ARCH_DMA_MINALIGN as default alignment for fs_read_alloc()
authorNam Cao <namcao@linutronix.de>
Thu, 7 Nov 2024 15:01:06 +0000 (16:01 +0100)
committerTom Rini <trini@konsulko.com>
Mon, 18 Nov 2024 14:23:56 +0000 (08:23 -0600)
The comment above fs_read_alloc() explains:

    @align: Alignment to use for memory allocation (0 for default)

However, in the actual implementation, there is no alignment when @align is
zero.

This current default is probably fine for most cases. But for some block
devices which transfer data via DMA, ARCH_DMA_MINALIGN is needed.

Change the default alignment to ARCH_DMA_MINALIGN.

Fixes: de7b5a8a1ac0 ("fs: Create functions to load and allocate a file")
Signed-off-by: Nam Cao <namcao@linutronix.de>
Tested-by: Javier Fernandez Pastrana <javier.pastrana@linutronix.de>
fs/fs.c
include/fs.h

diff --git a/fs/fs.c b/fs/fs.c
index 1afa0fbeaed9bebb5001c6f0587f94b7719ae57c..21a23efd932d730fa6893d331992a3aff54ac6c1 100644 (file)
--- a/fs/fs.c
+++ b/fs/fs.c
@@ -23,6 +23,7 @@
 #include <time.h>
 #include <ubifs_uboot.h>
 #include <btrfs.h>
+#include <asm/cache.h>
 #include <asm/global_data.h>
 #include <asm/io.h>
 #include <div64.h>
@@ -1001,6 +1002,9 @@ int fs_read_alloc(const char *fname, ulong size, uint align, void **bufp)
        char *buf;
        int ret;
 
+       if (!align)
+               align = ARCH_DMA_MINALIGN;
+
        buf = memalign(align, size + 1);
        if (!buf)
                return log_msg_ret("buf", -ENOMEM);
index 63727567cccfb2e0f9386ea96cf1d607a7f120f3..2474880385d4e6cc540d259b64fdceb6a36887fd 100644 (file)
@@ -325,7 +325,7 @@ int do_fs_types(struct cmd_tbl *cmdtp, int flag, int argc, char * const argv[]);
  *
  * @fname: Filename to read
  * @size: Size of file to read (must be correct!)
* @align: Alignment to use for memory allocation (0 for default)
  * @bufp: On success, returns the allocated buffer with the nul-terminated file
  *     in it
  * Return: 0 if OK, -ENOMEM if out of memory, -EIO if read failed
@@ -325,7 +325,7 @@ int do_fs_types(struct cmd_tbl *cmdtp, int flag, int argc, char * const argv[]);
  * @fname: Filename to read
  * @size: Size of file to read (must be correct!)
- * @align: Alignment to use for memory allocation (0 for default)
+ * @align: Alignment to use for memory allocation (0 for default: ARCH_DMA_MINALIGN)
  * @bufp: On success, returns the allocated buffer with the nul-terminated file
  *     in it